@@ -504,6 +504,8 @@ enum {
   SPVM_OPCODE_C_ID_CALL_CLASS_METHOD,
   SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD_STATIC,
   SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD,
+  SPVM_OPCODE_C_ID_GET_ADDRESS_OBJECT,
+  SPVM_OPCODE_C_ID_GET_ADDRESS_REF,
 };
 
 // An operation code is 128 bits
